# suck_lord_kelvin_cock

This is an automated Wi-Fi login program for the Kelvin Building. It has a store of some passcodes. Beyond this, it has a passcode command line option.

# setup

```Bash
pip install slokc
```

# usage

General usage using stored passcodes is as follows:

```Bash
suck_lord_kelvin_cock.py
```

Manual passcode specification can be made in a way like the following:

```Bash
suck_lord_kelvin_cock.py --passcode="dfae91"
```

A help message is accessible in the following way:

```Bash
suck_lord_kelvin_cock.py --help
```

![](https://i.imgur.com/yNKzPh7.png)

# passcodes

A source for passcodes is here: <http://www.physics.gla.ac.uk/dept-only/wlesscodes/>
